@@ -24,7 +24,7 @@
 
 import click
 
-from .service import purge, restart, start, status, stop
+from .service import purge, restart, start, status, stop, logs, config
 
 
 # Main entrypoint
@@ -54,6 +54,8 @@ cli.add_command(stop)
 cli.add_command(restart)
 cli.add_command(status)
 cli.add_command(purge)
+cli.add_command(logs)
+cli.add_command(config)
 
 if __name__ == "__main__":
     cli()
